@@ -8,16 +8,13 @@ For more information, refer to documentation on Notion.
 import boto3
 from botocore.exceptions import ClientError
 
-#put the mailing list into a config.py file
-maillist = ['recipient1@email.com','recipient2@email.com'] 
-
-def send_report(item_list):
+def send_report(item_list, maillist, subject):
     
-    SENDER = "Email Bot <mailbot@email.com>"
+    SENDER = "Email Bot <argusmailbot@gmail.com>"
     AWS_REGION = "us-west-2"
     CHARSET = "UTF-8"
     
-    SUBJECT = "Subject"
+    SUBJECT = subject
     client = boto3.client('ses',region_name=AWS_REGION)
     
     try:
